@@ -11,6 +11,7 @@
 //! These endpoints are used for querying and modifying projects and their resources.
 
 mod create;
+pub mod deploy_keys;
 mod edit;
 pub mod environments;
 pub mod hooks;
@@ -19,6 +20,7 @@ pub mod jobs;
 pub mod labels;
 pub mod members;
 pub mod merge_requests;
+pub mod merge_trains;
 pub mod milestones;
 pub mod pipelines;
 mod project;
@@ -27,6 +29,7 @@ pub mod protected_branches;
 pub mod protected_tags;
 pub mod releases;
 pub mod repository;
+pub mod variables;
 
 pub use self::create::AutoDevOpsDeployStrategy;
 pub use self::create::BuildGitStrategy;
@@ -35,18 +38,24 @@ pub use self::create::ContainerExpirationKeepN;
 pub use self::create::ContainerExpirationOlderThan;
 pub use self::create::ContainerExpirationPolicy;
 pub use self::create::ContainerExpirationPolicyBuilder;
+pub use self::create::ContainerExpirationPolicyBuilderError;
 pub use self::create::CreateProject;
 pub use self::create::CreateProjectBuilder;
+pub use self::create::CreateProjectBuilderError;
 pub use self::create::FeatureAccessLevel;
 pub use self::create::FeatureAccessLevelPublic;
 pub use self::create::MergeMethod;
+pub use self::create::SquashOption;
 
 pub use self::edit::EditProject;
 pub use self::edit::EditProjectBuilder;
+pub use self::edit::EditProjectBuilderError;
 
 pub use self::project::Project;
 pub use self::project::ProjectBuilder;
+pub use self::project::ProjectBuilderError;
 
 pub use self::projects::ProjectOrderBy;
 pub use self::projects::Projects;
 pub use self::projects::ProjectsBuilder;
+pub use self::projects::ProjectsBuilderError;
