@@ -13,25 +13,36 @@ mod comments;
 mod commit;
 mod commits;
 mod create_status;
+mod merge_requests;
 mod statuses;
 
 pub use self::comment::CommentOnCommit;
 pub use self::comment::CommentOnCommitBuilder;
+pub use self::comment::CommentOnCommitBuilderError;
 pub use self::comment::LineType;
 
 pub use self::comments::CommitComments;
 pub use self::comments::CommitCommentsBuilder;
+pub use self::comments::CommitCommentsBuilderError;
 
 pub use self::commit::Commit;
 pub use self::commit::CommitBuilder;
+pub use self::commit::CommitBuilderError;
 
 pub use self::commits::Commits;
 pub use self::commits::CommitsBuilder;
+pub use self::commits::CommitsBuilderError;
 pub use self::commits::CommitsOrder;
 
 pub use self::create_status::CommitStatusState;
 pub use self::create_status::CreateCommitStatus;
 pub use self::create_status::CreateCommitStatusBuilder;
+pub use self::create_status::CreateCommitStatusBuilderError;
 
 pub use self::statuses::CommitStatuses;
 pub use self::statuses::CommitStatusesBuilder;
+pub use self::statuses::CommitStatusesBuilderError;
+
+pub use self::merge_requests::MergeRequests;
+pub use self::merge_requests::MergeRequestsBuilder;
+pub use self::merge_requests::MergeRequestsBuilderError;
